# Copyright 2020 StackHut Limited (trading as Datapane)
# SPDX-License-Identifier: Apache-2.0

from .utils import DPError

__all__ = ["DPError"]
